@@ -14,7 +14,7 @@
 # limitations under the License.
 #
 
-__version__ = "5.10.2"
+__version__ = "5.10.3"
 
 import argparse
 import configparser
@@ -811,7 +811,7 @@ def _generate(source, config, ta_version, outputdir=None):
         outputdir, ta_name, "metadata", "default.meta"
     )
     if not os.path.exists(default_meta_conf_path):
-        os.makedirs(os.path.join(outputdir, ta_name, "metadata"))
+        os.makedirs(os.path.join(outputdir, ta_name, "metadata"), exist_ok=True)
         with open(default_meta_conf_path, "w") as default_meta_conf_fd:
             MetaConf().create_default(default_meta_conf_fd)
 
